# -*- coding: utf-8 -*-
# Copyright 2021 Red Hat
# GNU General Public License v3.0+
# (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type

"""
The L2_interfaces parser templates file. This contains
a list of parser definitions and associated functions that
facilitates both facts gathering and native command generation for
the given network resource.
"""

import re
from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.network_template import (
    NetworkTemplate,
)


class L2_interfacesTemplate(NetworkTemplate):
    def __init__(self, lines=None, module=None):
        super(L2_interfacesTemplate, self).__init__(
            lines=lines, tmplt=self, module=module
        )

    # fmt: off
    PARSERS = [
        {
            "name": "port",
            "getval": re.compile(
                r"""
                port(\s(?P<port>\S+))
                $""", re.VERBOSE),
            "result": {
                "port": "{{ port }}",
            },
        },
        {
            "name": "mode",
            "getval": re.compile(
                r"""
                \sswitchport\smode(\s(?P<mode>\S+))
                $""", re.VERBOSE),
            "result": {
                "mode": "{{ mode }}",
            },
        },
        {
            "name": "access_vlan",
            "getval": re.compile(
                r"""
                \sswitchport\saccess\svlan
                (\s(?P<vlan_id>\d+))
                $""", re.VERBOSE),
            "result": {
                "access_vlan": "{{ vlan_id }}",
            },
        },
        {
            "name": "trunk.allowed",
            "getval": re.compile(
                r"""
                \sswitchport\strunk\sallowed\svlan
                (\s(?P<vlan_id>(all|(([\d|-]+,*)+))))
                """, re.VERBOSE),
            "result": {
                "trunk": {
                    "allowed_vlan": "{{ vlan_id }}",
                },
            },
        },
        {
            "name": "trunk.native",
            "getval": re.compile(
                r"""
                \sswitchport\strunk\snative\svlan
                ((\s(?P<id>\d+))|(\s(?P<tag>tag)))
                $""", re.VERBOSE),
            "result": {
                "trunk": {
                    "native_vlan": {
                        "tag": "{{ true if tag is defined }}",
                        "vlan_id": "{{ id }}",
                    },
                },
            },
        },
        {
            "name": "hybrid.allowed",
            "getval": re.compile(
                r"""
                \sswitchport\shybrid\sallowed\svlan
                ((\s(?P<add>add))?(\s(?P<tag_status>tagged|untagged)))?
                (\s(?P<remove>remove))?
                (\s(?P<vlan_id>([\d|-]+,*)+))
                $""", re.VERBOSE),
            "result": {
                "hybrid": {
                    "allowed_vlan": [{
                        "add": "{{ true if add is defined }}",
                        "tag_status": "{{ tag_status }}",
                        "remove": "{{ true if remove is defined }}",
                        "vlan_id": "\"{{ vlan_id }}\"",
                    },],
                },
            },
        },
        {
            "name": "hybrid.native",
            "getval": re.compile(
                r"""
                \sswitchport\shybrid\snative\svlan
                (\s(?P<vlan_id>\d+))
                $""", re.VERBOSE),
            "result": {
                "hybrid": {
                    "native_vlan": "{{ vlan_id }}",
                },
            },
        },
    ]
    # fmt: on
